package com.fs.qw.controller;

import java.util.List;

import com.fs.qw.param.IPadServerLogParam;
import com.fs.qw.vo.QwIPadServerLogVO;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.fs.common.annotation.Log;
import com.fs.common.core.controller.BaseController;
import com.fs.common.core.domain.AjaxResult;
import com.fs.common.enums.BusinessType;
import com.fs.qw.domain.QwIpadServerLog;
import com.fs.qw.service.IQwIpadServerLogService;
import com.fs.common.utils.poi.ExcelUtil;
import com.fs.common.core.page.TableDataInfo;

/**
 * ipad服务器日志Controller
 *
 * @author fs
 * @date 2025-07-23
 */
@RestController
@RequestMapping("/qw/qwIpadServerLog")
public class QwIpadServerLogController extends BaseController
{
    @Autowired
    private IQwIpadServerLogService qwIpadServerLogService;

    /**
     * 查询ipad服务器日志列表
     */
    @PreAuthorize("@ss.hasPermi('qw:qwIpadServerLog:list')")
    @GetMapping("/list")
    public TableDataInfo list(QwIpadServerLog qwIpadServerLog)
    {
        startPage();
        List<QwIpadServerLog> list = qwIpadServerLogService.selectQwIpadServerLogList(qwIpadServerLog);
        return getDataTable(list);
    }

    /**
     * 查询ipad服务器日志列表
     */
    @PreAuthorize("@ss.hasPermi('qw:qwIpadServerLog:list')")
    @GetMapping("/ipadServerLogList")
    public TableDataInfo ipadServerLogList(IPadServerLogParam iPadServerLogParam)
    {
        startPage();
        List<QwIPadServerLogVO> list = qwIpadServerLogService.selectIpadServerLogList(iPadServerLogParam);
        return getDataTable(list);
    }

    /**
     * 导出ipad服务器日志列表
     */
    @PreAuthorize("@ss.hasPermi('qw:qwIpadServerLog:export')")
    @Log(title = "ipad服务器日志", businessType = BusinessType.EXPORT)
    @GetMapping("/export")
    public AjaxResult export(IPadServerLogParam qwIpadServerLog)
    {
        List<QwIPadServerLogVO> list = qwIpadServerLogService.selectIpadServerLogList(qwIpadServerLog);
        ExcelUtil<QwIPadServerLogVO> util = new ExcelUtil<QwIPadServerLogVO>(QwIPadServerLogVO.class);
        return util.exportExcel(list, "ipad服务器日志数据");
    }

    /**
     * 获取ipad服务器日志详细信息
     */
    @PreAuthorize("@ss.hasPermi('qw:qwIpadServerLog:query')")
    @GetMapping(value = "/{id}")
    public AjaxResult getInfo(@PathVariable("id") Long id)
    {
        return AjaxResult.success(qwIpadServerLogService.selectQwIpadServerLogById(id));
    }

    /**
     * 新增ipad服务器日志
     */
    @PreAuthorize("@ss.hasPermi('qw:qwIpadServerLog:add')")
    @Log(title = "ipad服务器日志", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody QwIpadServerLog qwIpadServerLog)
    {
        return toAjax(qwIpadServerLogService.insertQwIpadServerLog(qwIpadServerLog));
    }

    /**
     * 修改ipad服务器日志
     */
    @PreAuthorize("@ss.hasPermi('qw:qwIpadServerLog:edit')")
    @Log(title = "ipad服务器日志", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody QwIpadServerLog qwIpadServerLog)
    {
        return toAjax(qwIpadServerLogService.updateQwIpadServerLog(qwIpadServerLog));
    }

    /**
     * 删除ipad服务器日志
     */
    @PreAuthorize("@ss.hasPermi('qw:qwIpadServerLog:remove')")
    @Log(title = "ipad服务器日志", businessType = BusinessType.DELETE)
    @DeleteMapping("/{ids}")
    public AjaxResult remove(@PathVariable Long[] ids)
    {
        return toAjax(qwIpadServerLogService.deleteQwIpadServerLogByIds(ids));
    }
}
